@@ -11,7 +11,7 @@ def lookupFreq(word):
     qs = Spelling.objects.filter(Label=word).order_by('-Word__Frequency')
     total = 0.0
     for q in qs:
-        total += q.Frequency
+        total += q.Word.Frequency
     return total
 
 #def lookupStress(word,freqDict):
